#!/usr/local/bin/perl
#***************************************************************************
#*          Copyright 2000 DBAmon Software, All Rights Reserved            *
#***************************************************************************
# =========================================================
# dbamon_create_tables.pl
#
#  This module invokes the dbamon_orastat module which is
#  included with DBAmon.
#
# Changes:
# 
#   bb 12Jun00 - Initial
# =========================================================

$P = "dbamon_create_tables.pl";
$ENV{'PATH'} = "/opt/dbamon/bin:$ENV{'PATH'}";
$os = $ENV{"ORACLE_SID"};

#------------------------------------------------------------------------------
sub msg
#------------------------------------------------------------------------------
{
  $msgmsg = $_[0];
  chop($date = `date +%Y/%m/%d-%H:%M:%S`);
  print "$date ${P} | $msgmsg\n";
}

#------------------------------------------------------------------------------
sub error
#------------------------------------------------------------------------------
{
  $msg = $_[0];
  &msg("=============================================================");
  &msg("Fatal Error: $msg");
  &msg("=============================================================");
  &msg("Exiting rc=1");
  exit 1;
}

#------------------------------------------------------------------------------
sub ORAcreateUser
#------------------------------------------------------------------------------
{
  # Ensure that DBAmon user exists
  &msg("Seeing if DBAMON user exists");
  if (system("dbamon_orastat -us | grep 'DBAMON'") != 0)
  {
    &msg("Oracle user DBAMON does not exist - creating");

    ##while ($pw eq "")
    ##{
    ##  print "Enter password for user DBAMON that I am creating ===> ";
    ##  chop($pw = <STDIN>);
    ##}

    chop($pw = `grep 'ORACLE_Password:' /opt/dbamon/adm/dbamonrc | grep -v '^#' | awk '{ print \$2 }'`);

    if ($pw eq "")
    {
      &error("Before running this, you must specify the Oracle password for DB user dbamon in dbamonrc (ORACLE_Password:)");
    }
   

    #&msg("Looking for default TS to assign to user DBAMON");
    #$ts = `dbamon_orastat -ts | grep USER | head -1 | awk '{ print \$1 }'`;
    #chop $ts;

    print "What tablespace should I use as the default tablespace for user dbamon? ===> ";
    chop($ts = <STDIN>);

    &msg("Looking for TEMP to assign to user DBAMON");
    $tm = `dbamon_orastat -ts | grep TEMP | head -1 | awk '{ print \$1 }'`;
    chop $tm;
    while ($tm eq "")
    {
      print "Could not determine what TEMP Tablespace to use for user DBAmon";
      print "What tablespace should I use? ===> ";
      chop($tm = <STDIN>);
    }

    system("sqlplus /nolog <<!
      connect / as sysdba;
      create user DBAMON identified by $pw
      default tablespace $ts temporary tablespace $tm;
      grant connect to DBAMON;
      grant unlimited tablespace to DBAMON;
    !");
    if (system("dbamon_orastat -us | grep 'DBAMON'") != 0)
    {
      &error("User DBAMON still does not exist - Something is wrong"); 
    }
  }
}

#------------------------------------------------------------------------------
sub runSQL
#------------------------------------------------------------------------------
{
  $tbl = $_[0];
  &msg("Seeing if table DBAMON.$tbl exists");

  system("echo 'connect / as sysdba\nselect count(*) from DBAMON.$tbl;' | sqlplus /nolog");

  if (system("echo 'connect / as sysdba\nselect count(*) from DBAMON.$tbl;' | sqlplus /nolog | grep 'does not exist'") != 0)
  {
    &msg("Table already exists - no action will be taken");
    return;
  }

  &msg("Creating $tbl from SQL /opt/dbamon/sql/table_${tbl}.sql");
  $rc = system("sqlplus /nolog <<!
    connect / as sysdba;
    @/opt/dbamon/sql/table_${tbl}.sql;
  !");
  if ($rc != 0) 
  {
    &error("Table create for $tbl failed");
  }

  if (system("echo 'connect / as sysdba;\nselect count(*) from DBAMON.$tbl' | sqlplus /nolog | grep 'does not exist'") == 0)
  {
    &msg("Something is wrong - Table $tbl does not exist after I tried to create it - check above error message and rerun");
    return;
  }

  &msg("Table $tbl created successfully");
}

#------------------------------------------------------------------------------
# Main
#------------------------------------------------------------------------------

if ($os eq "")
{
  &error("Env ORACLE_SID must be set to the DB that will be used to store DBAmon data");
}

#$id = `whoami`;
#chop $id;
$id =  (getpwuid("$>")) [0]; 
&msg("Starting - id=$id = ORACLE_SID=$os will be used to store DBAmon data");

if (substr($id,0,3) ne "ora")
{
  &error("$P Must Be Run By oracle or ora* (your id=$id)");
}

&ORAcreateUser;

# Process each table definition in /opt/dbamon/sql

$dir = "/opt/dbamon/sql/";
chdir("$dir");
opendir(IN_DIR, "$dir") || die "can't opendir $dir - $!";
@in_files = readdir IN_DIR;
foreach $file (@in_files)
{
  if ($file =~ /^table_/)
  {
    $z = length($file) - 10;
    $table = substr($file,6,$z);
    msg("Found table definition file=$file table=$table");
    &runSQL("$table");
  }
}

&msg("Done");

exit 0;
