# -----------------------------------------------------------------------------
sub oraSGA
{
  ($thishost) = @_;
  #
  # Check SGA measurements captured in oraUp
  #

  if ($t_sga_w[$thishost] eq "N")
  {
    &logit("(Not Selected (T_SGA_Full: is N)",$thishost);
    return 1;
  }

  if ($up[$thishost] ne "Y")
  {
    logit("(Down/Inhibited)",$thishost);
    return 1;
  }

  if (&check_inhib($thishost) eq "Y")
  {
    $up[$thishost] = "I";
    return;
  }

  if ($sw_version_num[$thishost] < 8)
  {
    logit("(SGA Checking only works for Oracle version >= 8)",$thishost);
    return 1;
  }

  if ($t_sga_w[$thishost] eq "") { $t_sga_w[$thishost] = $df_t_sga_w }
  if ($t_sga_c[$thishost] eq "") { $t_sga_c[$thishost] = $df_t_sga_c }
  ##print "t_sga_w[$thishost]=$t_sga_w[$thishost] t_sga_c[$thishost]=$t_sga_c[$thishost]\n";

  if ($sga_pct[$thishost] >= $t_sga_c[$thishost])
  {
    &event("C",$thishost,"Oracle SGA is $sga_pct[$thishost]% Full (Critical threshold: $t_sga_c[$thishost]%)","SGAFull","DBA660");
    ##print "SGACRIT $title[$thishost] sga_pct=$sga_pct[$thishost] sga_size=$sga_size[$thishost] sga_free=$sga_free[$thishost]\n";
  }
  elsif ($sga_pct[$thishost] >= $t_sga_w[$thishost])
  {
    &event("W",$thishost,"Oracle SGA is $sga_pct[$thishost]% Full (Warning threshold: $t_sga_w[$thishost]%)","SGAFull","DBA660");
    ##print "SGAWARN $title[$thishost] sga_pct=$sga_pct[$thishost] sga_size=$sga_size[$thishost] sga_free=$sga_free[$thishost]\n";
  }

  $zused = $sga_size[$thishost] - $sga_free[$thishost];

  &logDetails($thishost,"<h3>Oracle SGA System Global Area Status</h3>");
  &logDetails($thishost,"<table border=1 bgcolor=antiquewhite>");
  &logDetails($thishost,"<tr bgcolor=slate><th>Parameter<th>Value<th>Comments</tr>");
  &logDetails($thishost,"<tr><td>$f_s<b>SGA Size (from init.ora):</b> <td align=right>$f_s $sga_size[$thishost] <td>$f_s (bytes)");
  &logDetails($thishost,"<tr><td>$f_s<b>SGA Used Bytes:</b>           <td align=right>$f_s $zused ");
  &logDetails($thishost,"<tr><td>$f_s<b>SGA Free Bytes:</b>           <td align=right>$f_s $sga_free[$thishost] ");
  &logDetails($thishost,"<tr><td>$f_s<b>SGA Percent Full:</b>         <td align=right>$f_s $sga_pct[$thishost]%");
  &logDetails($thishost,"</table><hr>");

  logit("SGA is $sga_pct[$thishost]% full - Thresholds: $t_sga_w[$thishost]/$t_sga_c[$thishost]",$thishost);
}
# -----------------------------------------------------------------------------
1;
